<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:include href="../../../../share/XSLT/descriptionTop.xslt"/>
<xsl:include href="../../../../share/XSLT/indexMenu.xslt"/>
<xsl:include href="../../../../share/XSLT/bottomLinks.xsl"/>

<xsl:include href="allRefs.xslt"/>





<xsl:output method="xhtml:xhtml"/>

<xsl:variable name="menu">
  <groups xmlns="">
    <group id="interfaces" href="./_interfaceIndex.html" title="interfaces"/>
    <group id="attributes"  href="./_attributeIndex.html"  title="attributes"/>
    <group id="methods" href="./_methodIndex.html" title="methods"/>
    <!--group id="all" href="./_allIndex.html" title="all refs"/-->
  </groups>
</xsl:variable>

<!-- 
<xsl:variable name="zvonItemid" select="document('../frontpage.xml')/frontPage/@idref"/>

<xsl:variable name="examplesDoc" select="document('../examples.xml')/examples"/>
-->




<xsl:template match="/">
  <!-- build modules' indexes -->
  <xsl:apply-templates select="//module"/>
  <!-- build refs index -->
  <xsl:call-template name="allRefs"/>
</xsl:template>

<xsl:template match="module">

  <xsl:param name="module"><xsl:value-of select="@name"/></xsl:param>
  <xsl:message>
    Module: <xsl:value-of select="$module"/>
  </xsl:message>

  <xsl:document href="{$pwd}Output/{$module}/_interfaceIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (interfaces) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">interfaces</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>interface</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}Output/{$module}/_attributeIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (attributes) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">attributes</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>attribute</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface/attribute">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}Output/{$module}/_methodIndex.html">
    <html>
      <head>
        <title> TOC - DOM2 reference (methods) </title>
        <link href="../global.css" rel="stylesheet" type="text/css" />
        <link href="../reference.css" rel="stylesheet" type="text/css" />
        <link href="../example.css" rel="stylesheet" type="text/css" />
      </head>
      <body>
        <xsl:call-template name="index-header-special">
          <xsl:with-param name="on">methods</xsl:with-param>
          <xsl:with-param name="id" select="$zvonItemid"/>
          <xsl:with-param name="sectionId" select="$module"/>
          <xsl:with-param name="url"><xsl:text>method</xsl:text></xsl:with-param>
        </xsl:call-template> 
        <table width="100%">
          <xsl:apply-templates select="descendant::interface/method">
            <xsl:sort select="@name"/>
          </xsl:apply-templates>
        </table>
      </body>
    </html>
  </xsl:document>

</xsl:template>
 
<xsl:template match="interface">
  <xsl:variable name="desiredName"><xsl:value-of select="@name"/>.html</xsl:variable>
  <tr><td><a class="interface" href="interface_{$desiredName}" target="mainWindow"><xsl:value-of select="@name"/></a></td></tr>
</xsl:template>

<xsl:template match="interface/attribute">
  <tr><td><a class="attributeFg" href="attribute_{@name}_{../@name}.html" target="mainWindow" title="interface {../@name}"><xsl:value-of select="@name"/></a>&#160;<xsl:call-template name="isExample"><xsl:with-param name="onNode" value="."/></xsl:call-template>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>]</span></td></tr>
</xsl:template>

<xsl:template match="interface/method">
  <tr><td>
    <a class="methodFg" href="method_{@name}_{../@name}.html" target="mainWindow" title="interface {../@name}"><xsl:value-of select="@name"/>()</a>&#160;<xsl:call-template name="isExample"><xsl:with-param name="onNode" value="."/></xsl:call-template>&#160;<span class="longName">[<xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>()]</span>
  </td></tr>
</xsl:template>



<xsl:template name="isExample">
  <xsl:param name="onNode"/>
  <xsl:if test="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]">
    <sup>ex</sup>
  </xsl:if>
</xsl:template>

<xsl:template name="index-header-special">
  <xsl:param name="on"/>	<!-- what is highlited -->
  <xsl:param name="id"/>
  <xsl:param name="sectionId"/>	<!-- what is opened -->
  <xsl:param name="url"/>
  <xsl:param name="levelsBack">2</xsl:param>
  <xsl:variable name="field">
    <items xmlns="">
      <a id="Core" class="naviBlack" href="../Core/_{$url}Index.html">Core</a>
      <a id="HTML" class="naviBlack" href="../HTML/_{$url}Index.html">HTML</a>
      <a id="Views" class="naviBlack" href="../Views/_{$url}Index.html">Views</a>
      <!--a id="Style" class="naviBlack" href="../Style/_{$url}Index.html">Style</a-->
      <a id="Events" class="naviBlack" href="../Events/_{$url}Index.html">Events</a>
      <a id="TraversalRange" class="naviBlack" href="../TraversalRange/_{$url}Index.html">Traversal and Range</a>
    </items>
  </xsl:variable>
  <!-- top ZVON navigation -->
  <xsl:call-template name="tinyTopMenu">
    <xsl:with-param name="id" select="'z20010208'"/>
    <xsl:with-param name="levelsBack" select="$levelsBack"/>
  </xsl:call-template>
  <!-- TREE modules navigation -->
  <table width="100%" class="descriptionMenu" border="0">
  <tr>
    <td colspan="2" class="descriptionMenu">
    <ul>
      <xsl:for-each select="$field/items/a">
        <li>
          <xsl:choose>
            <xsl:when test="@id = $sectionId">
              - <xsl:value-of select="$sectionId"/>
              <ul>
                <xsl:apply-templates select="$menu/groups/*" mode="indexMenu">
                  <xsl:with-param name="id" select="$on"/>
                </xsl:apply-templates>
              </ul>
            </xsl:when>
            <xsl:otherwise>
              + <a class="menu" href=""><xsl:copy-of select="."/></a>
            </xsl:otherwise>
          </xsl:choose>
        </li>
      </xsl:for-each>
    </ul>
    </td>
  </tr><tr>
    <td align="left">
      <xsl:text>&#160;&#160;&#160; ( </xsl:text>
      <a id="allrefs" class="naviBlack" href="../_exceptions.html" target="mainWindow">exceptions</a>
      <xsl:text> ) </xsl:text>
    </td>
    <td align="right">
      <xsl:text>( </xsl:text>
      <a id="allrefs" class="naviBlack" href="../_allIndex.html" target="mainWindow">all refs</a>
      <xsl:text> ) &#160;&#160;&#160;</xsl:text>
    </td>
  </tr>
  </table>
  <hr />
</xsl:template>


<!-- ZVON related -->
<xsl:template name="descriptionTop">
  <xsl:call-template name="share_descriptionTop">
    <xsl:with-param name="id" select="$zvonItemid"/>
    <xsl:with-param name="levelsBack" select="2"/>
  </xsl:call-template>
</xsl:template>
 
<xsl:template name="footer">
  <xsl:call-template name="bottomLinks"/>
</xsl:template>



</xsl:stylesheet>